@@ -17,10 +17,10 @@ use League\CommonMark\ConverterInterface;
 use League\CommonMark\Environment\Environment;
 use League\CommonMark\Extension\Autolink\AutolinkExtension;
 use League\CommonMark\Extension\CommonMark\CommonMarkCoreExtension;
-use League\CommonMark\Tests\Functional\AbstractLocalDataTest;
+use League\CommonMark\Tests\Functional\AbstractLocalDataTestCase;
 use League\CommonMark\Xml\MarkdownToXmlConverter;
 
-final class AutolinkXmlTest extends AbstractLocalDataTest
+final class AutolinkXmlTest extends AbstractLocalDataTestCase
 {
     /**
      * @param array<string, mixed> $config
@@ -37,8 +37,8 @@ final class AutolinkXmlTest extends AbstractLocalDataTest
     /**
      * {@inheritDoc}
      */
-    public function dataProvider(): iterable
+    public static function dataProvider(): iterable
     {
-        yield from $this->loadTests(__DIR__ . '/xml', '*', '.md', '.xml');
+        yield from self::loadTests(__DIR__ . '/xml', '*', '.md', '.xml');
     }
 }
