@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 /*
  * This file is part of the league/commonmark package.
  *
@@ -11,16 +13,17 @@
 
 namespace League\CommonMark\Tests\Unit\Event;
 
-use League\CommonMark\Block\Element\Document;
-use League\CommonMark\DocParser;
-use League\CommonMark\Environment;
+use League\CommonMark\Environment\Environment;
 use League\CommonMark\Event\DocumentPreParsedEvent;
+use League\CommonMark\Extension\CommonMark\CommonMarkCoreExtension;
 use League\CommonMark\Input\MarkdownInput;
+use League\CommonMark\Node\Block\Document;
+use League\CommonMark\Parser\MarkdownParser;
 use PHPUnit\Framework\TestCase;
 
 final class DocumentPreParsedEventTest extends TestCase
 {
-    public function testGetDocument()
+    public function testGetDocument(): void
     {
         $document = new Document();
         $markdown = new MarkdownInput('');
@@ -31,16 +34,17 @@ final class DocumentPreParsedEventTest extends TestCase
         $this->assertSame($markdown, $event->getMarkdown());
     }
 
-    public function testEventDispatchedAtCorrectTime()
+    public function testEventDispatchedAtCorrectTime(): void
     {
         $wasCalled = false;
 
-        $environment = Environment::createCommonMarkEnvironment();
-        $environment->addEventListener(DocumentPreParsedEvent::class, function (DocumentPreParsedEvent $event) use (&$wasCalled) {
+        $environment = new Environment();
+        $environment->addExtension(new CommonMarkCoreExtension());
+        $environment->addEventListener(DocumentPreParsedEvent::class, static function (DocumentPreParsedEvent $event) use (&$wasCalled): void {
             $wasCalled = true;
         });
 
-        $parser = new DocParser($environment);
+        $parser = new MarkdownParser($environment);
         $parser->parse('hello world');
 
         $this->assertTrue($wasCalled);
