@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 /*
  * This file is part of the league/commonmark package.
  *
@@ -13,7 +15,7 @@ namespace League\CommonMark\Tests\Unit\Extension\Mention\Generator;
 
 use League\CommonMark\Extension\Mention\Generator\StringTemplateLinkGenerator;
 use League\CommonMark\Extension\Mention\Mention;
-use League\CommonMark\Inline\Element\Text;
+use League\CommonMark\Node\Inline\Text;
 use PHPUnit\Framework\TestCase;
 
 final class StringTemplateLinkGeneratorTest extends TestCase
@@ -22,13 +24,13 @@ final class StringTemplateLinkGeneratorTest extends TestCase
     {
         $generator = new StringTemplateLinkGenerator('https://www.twitter.com/%s');
 
-        $mention = $generator->generateMention(new Mention('@', 'colinodell'));
-        assert($mention instanceof Mention);
+        $mention = $generator->generateMention(new Mention('test', '@', 'colinodell'));
+        \assert($mention instanceof Mention);
 
         $this->assertSame('https://www.twitter.com/colinodell', $mention->getUrl());
 
         $label = $mention->firstChild();
-        assert($label instanceof Text);
-        $this->assertSame('@colinodell', $label->getContent());
+        \assert($label instanceof Text);
+        $this->assertSame('@colinodell', $label->getLiteral());
     }
 }
